-- Databricks notebook source

SELECT COL1 FROM TABLE1

-- COMMAND ----------

SELECT COL2 FROM TABLE2

-- COMMAND ----------

SELECT COL3 FROM TABLE3;
SELECT COL4 FROM TABLE4;
